@@ -62,7 +62,6 @@ class HWForm : public QMainWindow
         HWForm(QWidget *parent = 0, QString styleSheet = "");
         Ui_HWForm ui;
         static GameUIConfig * config;
-        void updateXfire();
         void exit();
         void setButtonDescription(QString desc);
         void backDescription();
@@ -75,9 +74,9 @@ class HWForm : public QMainWindow
         void GoToSaves();
         void GoToDemos();
         void GoToNet();
-        void GoToSelectWeapon();
-        void GoToSelectWeaponSet(int index);
-        void GoToSelectNewWeapon();
+        void GoToEditWeapons();
+        void GoToNewWeapons();
+        void GoToWeapons(int index);
         void GoToScheme(int index);
         void GoToEditScheme();
         void GoToNewScheme();
@@ -96,7 +95,7 @@ class HWForm : public QMainWindow
         void DeleteWeaponSet();
         void SimpleGame();
         void PlayDemo();
-        void startTraining(const QString&);
+        void startTraining(const QString&, const QString&);
         void StartCampaign();
         void NetConnect();
         void NetConnectServer(const QString & host, quint16 port);
@@ -124,10 +123,14 @@ class HWForm : public QMainWindow
         void GetRecord(RecordType type, const QByteArray & record);
         void CreateNetGame();
         void UpdateWeapons();
+        void DeleteWeapons(QString weaponsName);
+        void AddWeapons(QString weaponsName, QString ammo);
+        void EditWeapons(QString oldWeaponsName, QString newWeaponsName, QString ammo);
         void onFrontendFullscreen(bool value);
         void onFrontendEffects(bool value);
         void Music(bool checked);
         void UpdateCampaignPage(int index);
+        void UpdateCampaignPageTeam(int index);
         void UpdateCampaignPageProgress(int index);
         void UpdateCampaignPageMission(int index);
         void InitCampaignPage();
