@@ -43,6 +43,12 @@ void TeamSelWidget::addTeam(HWTeam team)
         blockSignals(false);
         connect(framePlaying->getTeamWidget(team), SIGNAL(teamColorChanged(const HWTeam&)),
                 this, SLOT(proxyTeamColorChanged(const HWTeam&)));
+
+        // Hide team notice if at least two teams.
+        if (curPlayingTeams.size() >= 2)
+        {
+            numTeamNotice->hide();
+        }
     }
     else
     {
@@ -133,6 +139,11 @@ void TeamSelWidget::removeNetTeam(const HWTeam& team)
         QObject::disconnect(framePlaying->getTeamWidget(*itPlay), SIGNAL(teamStatusChanged(HWTeam)));
         framePlaying->removeTeam(team);
         curPlayingTeams.erase(itPlay);
+        // Show team notice if less than two teams.
+        if (curPlayingTeams.size() < 2)
+        {
+            numTeamNotice->show();
+        }
     }
     else
     {
@@ -229,15 +240,17 @@ void TeamSelWidget::changeTeamStatus(HWTeam team)
     emit setEnabledGameStart(curPlayingTeams.size()>1);
 }
 
-void TeamSelWidget::addScrArea(FrameTeams* pfteams, QColor color, int fixedHeight)
+void TeamSelWidget::addScrArea(FrameTeams* pfteams, QColor color, int minHeight, int maxHeight, bool setFrame)
 {
     VertScrArea* area = new VertScrArea(color);
     area->setWidget(pfteams);
-    mainLayout.addWidget(area, 30);
-    if (fixedHeight > 0)
+    mainLayout.addWidget(area);
+    if (minHeight > 0)
+        area->setMinimumHeight(minHeight);
+    if (maxHeight > 0)
+        area->setMaximumHeight(maxHeight);
+    if (setFrame)
     {
-        area->setMinimumHeight(fixedHeight);
-        area->setMaximumHeight(fixedHeight);
         area->setStyleSheet(
             "FrameTeams{"
             "border: solid;"
@@ -263,8 +276,8 @@ TeamSelWidget::TeamSelWidget(QWidget* parent) :
 
     QPalette p;
     p.setColor(QPalette::Window, QColor(0x00, 0x00, 0x00));
-    addScrArea(framePlaying, p.color(QPalette::Window).light(105), 150);
-    addScrArea(frameDontPlaying, p.color(QPalette::Window).dark(105), 0);
+    addScrArea(framePlaying, p.color(QPalette::Window).light(105), 161, 325, true);
+    addScrArea(frameDontPlaying, p.color(QPalette::Window).dark(105), 80, 0, false);
 
     this->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
     this->setMinimumWidth(200);
@@ -292,6 +305,8 @@ void TeamSelWidget::resetPlayingTeams(const QList<HWTeam>& teamslist)
     foreach(HWTeam team, teamslist)
         addTeam(team);
 
+    numTeamNotice->show();
+
     repaint();
 }
 
@@ -310,6 +325,17 @@ QList<HWTeam> TeamSelWidget::getNotPlayingTeams() const
     return m_curNotPlayingTeams;
 }
 
+unsigned short TeamSelWidget::getNumHedgehogs() const
+{
+    unsigned short numHogs = 0;
+    QList<HWTeam>::const_iterator team;
+    for(team = curPlayingTeams.begin(); team != curPlayingTeams.end(); ++team)
+    {
+        numHogs += (*team).numHedgehogs();
+    }
+    return numHogs;
+}
+
 void TeamSelWidget::pre_changeTeamStatus(const HWTeam & team)
 {
     //team.setColor(framePlaying->getNextColor());
